
|CircleCI|_ |ReadTheDocs|_ |PyPIversion|_ |PyPIpythonversion|_ |Style|_ |License|_ 

.. |CircleCI| image:: https://circleci.com/gh/LocalCascadeEnsemble/LCE/tree/main.svg?style=shield
.. _CircleCI: https://circleci.com/gh/LocalCascadeEnsemble/LCE/tree/main
   
.. |ReadTheDocs| image:: https://readthedocs.org/projects/lce/badge/?version=latest
.. _ReadTheDocs: https://lce.readthedocs.io/en/latest/?badge=latest

.. |PyPIversion| image:: https://badge.fury.io/py/lcensemble.svg
.. _PyPIversion: https://pypi.python.org/pypi/lcensemble/

.. |PyPIpythonversion| image:: https://img.shields.io/pypi/pyversions/lcensemble.svg
.. _PyPIpythonversion: https://pypi.python.org/pypi/lcensemble/

.. |Style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
.. _Style: https://github.com/psf/black

.. |License| image:: https://img.shields.io/github/license/LocalCascadeEnsemble/LCE.svg
.. _License: https://pypi.python.org/pypi/lcensemble/


   
| **Local Cascade Ensemble (LCE)** is a *high-performing*, *scalable* and *user-friendly* machine learning method for the general tasks of **Classification** and **Regression**.
| In particular, LCE:
 
- Enhances the prediction performance of Random Forest and XGBoost by combining their strengths and adopting a complementary diversification approach
- Supports parallel processing to ensure scalability
- Handles missing data by design
- Adopts scikit-learn API for the ease of use
- Adheres to scikit-learn conventions to allow interaction with scikit-learn pipelines and model selection tools
- Is released in open source and commercially usable - Apache 2.0 license

An article introducing LCE and illustrative code examples has been published in `Towards Data Science <https://towardsdatascience.com/random-forest-or-xgboost-it-is-time-to-explore-lce-2fed913eafb8?source=friends_link&sk=8cba14ad36f7662d07e842d03944a316>`_.


Installation
~~~~~~~~~~~~

LCE package can be installed using ``pip``::

	pip install lcensemble


Documentation
~~~~~~~~~~~~~

LCE documentation, including API documentation and general examples, can be found `here <https://lce.readthedocs.io/en/latest/>`_.


Reference
~~~~~~~~~

The full information about LCE design and evaluation can be found in the associated `journal paper <https://hal.inria.fr/hal-03599214/document>`_:

.. [1] Fauvel, K., E. Fromont, V. Masson, P. Faverdin and A. Termier. XEM: An Explainable-by-Design Ensemble Method for Multivariate Time Series Classification. Data Mining and Knowledge Discovery, 36(3):917–957, 2022